# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/base/node/v1beta1/query.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cosmos/base/node/v1beta1/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$cosmos/base/node/v1beta1/query.proto\x12\x18\x63osmos.base.node.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x14gogoproto/gogo.proto\"\x0f\n\rConfigRequest\"b\n\x0e\x43onfigResponse\x12\x19\n\x11minimum_gas_price\x18\x01 \x01(\t\x12\x1b\n\x13pruning_keep_recent\x18\x02 \x01(\t\x12\x18\n\x10pruning_interval\x18\x03 \x01(\t\"\x0f\n\rStatusRequest\"\x9e\x01\n\x0eStatusResponse\x12\x1d\n\x15\x65\x61rliest_store_height\x18\x01 \x01(\x04\x12\x0e\n\x06height\x18\x02 \x01(\x04\x12\x33\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01\x12\x10\n\x08\x61pp_hash\x18\x04 \x01(\x0c\x12\x16\n\x0evalidator_hash\x18\x05 \x01(\x0c\x32\x99\x02\n\x07Service\x12\x85\x01\n\x06\x43onfig\x12\'.cosmos.base.node.v1beta1.ConfigRequest\x1a(.cosmos.base.node.v1beta1.ConfigResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /cosmos/base/node/v1beta1/config\x12\x85\x01\n\x06Status\x12\'.cosmos.base.node.v1beta1.StatusRequest\x1a(.cosmos.base.node.v1beta1.StatusResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /cosmos/base/node/v1beta1/statusB/Z-github.com/cosmos/cosmos-sdk/client/grpc/nodeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.base.node.v1beta1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/cosmos/cosmos-sdk/client/grpc/node'
  _globals['_STATUSRESPONSE'].fields_by_name['timestamp']._loaded_options = None
  _globals['_STATUSRESPONSE'].fields_by_name['timestamp']._serialized_options = b'\220\337\037\001'
  _globals['_SERVICE'].methods_by_name['Config']._loaded_options = None
  _globals['_SERVICE'].methods_by_name['Config']._serialized_options = b'\202\323\344\223\002\"\022 /cosmos/base/node/v1beta1/config'
  _globals['_SERVICE'].methods_by_name['Status']._loaded_options = None
  _globals['_SERVICE'].methods_by_name['Status']._serialized_options = b'\202\323\344\223\002\"\022 /cosmos/base/node/v1beta1/status'
  _globals['_CONFIGREQUEST']._serialized_start=151
  _globals['_CONFIGREQUEST']._serialized_end=166
  _globals['_CONFIGRESPONSE']._serialized_start=168
  _globals['_CONFIGRESPONSE']._serialized_end=266
  _globals['_STATUSREQUEST']._serialized_start=268
  _globals['_STATUSREQUEST']._serialized_end=283
  _globals['_STATUSRESPONSE']._serialized_start=286
  _globals['_STATUSRESPONSE']._serialized_end=444
  _globals['_SERVICE']._serialized_start=447
  _globals['_SERVICE']._serialized_end=728
# @@protoc_insertion_point(module_scope)



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.dydxprotocol.listing import params_pb2 as _params_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ("hard_cap_for_markets", "listing_vault_deposit_params")
    HARD_CAP_FOR_MARKETS_FIELD_NUMBER: _ClassVar[int]
    LISTING_VAULT_DEPOSIT_PARAMS_FIELD_NUMBER: _ClassVar[int]
    hard_cap_for_markets: int
    listing_vault_deposit_params: _params_pb2.ListingVaultDepositParams
    def __init__(self, hard_cap_for_markets: _Optional[int] = ..., listing_vault_deposit_params: _Optional[_Union[_params_pb2.ListingVaultDepositParams, _Mapping]] = ...) -> None: ...



from v4_proto.cosmos.group.v1 import types_pb2 as _types_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ("group_seq", "groups", "group_members", "group_policy_seq", "group_policies", "proposal_seq", "proposals", "votes")
    GROUP_SEQ_FIELD_NUMBER: _ClassVar[int]
    GROUPS_FIELD_NUMBER: _ClassVar[int]
    GROUP_MEMBERS_FIELD_NUMBER: _ClassVar[int]
    GROUP_POLICY_SEQ_FIELD_NUMBER: _ClassVar[int]
    GROUP_POLICIES_FIELD_NUMBER: _ClassVar[int]
    PROPOSAL_SEQ_FIELD_NUMBER: _ClassVar[int]
    PROPOSALS_FIELD_NUMBER: _ClassVar[int]
    VOTES_FIELD_NUMBER: _ClassVar[int]
    group_seq: int
    groups: _containers.RepeatedCompositeFieldContainer[_types_pb2.GroupInfo]
    group_members: _containers.RepeatedCompositeFieldContainer[_types_pb2.GroupMember]
    group_policy_seq: int
    group_policies: _containers.RepeatedCompositeFieldContainer[_types_pb2.GroupPolicyInfo]
    proposal_seq: int
    proposals: _containers.RepeatedCompositeFieldContainer[_types_pb2.Proposal]
    votes: _containers.RepeatedCompositeFieldContainer[_types_pb2.Vote]
    def __init__(self, group_seq: _Optional[int] = ..., groups: _Optional[_Iterable[_Union[_types_pb2.GroupInfo, _Mapping]]] = ..., group_members: _Optional[_Iterable[_Union[_types_pb2.GroupMember, _Mapping]]] = ..., group_policy_seq: _Optional[int] = ..., group_policies: _Optional[_Iterable[_Union[_types_pb2.GroupPolicyInfo, _Mapping]]] = ..., proposal_seq: _Optional[int] = ..., proposals: _Optional[_Iterable[_Union[_types_pb2.Proposal, _Mapping]]] = ..., votes: _Optional[_Iterable[_Union[_types_pb2.Vote, _Mapping]]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from v4_proto.cosmos.bank.v1beta1 import tx_pb2 as cosmos_dot_bank_dot_v1beta1_dot_tx__pb2

GRPC_GENERATED_VERSION = '1.75.1'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in cosmos/bank/v1beta1/tx_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class MsgStub(object):
    """Msg defines the bank Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Send = channel.unary_unary(
                '/cosmos.bank.v1beta1.Msg/Send',
                request_serializer=cosmos_dot_bank_dot_v1beta1_dot_tx__pb2.MsgSend.SerializeToString,
                response_deserializer=cosmos_dot_bank_dot_v1beta1_dot_tx__pb2.MsgSendResponse.FromString,
                _registered_method=True)
        self.MultiSend = channel.unary_unary(
                '/cosmos.bank.v1beta1.Msg/MultiSend',
                request_serializer=cosmos_dot_bank_dot_v1beta1_dot_tx__pb2.MsgMultiSend.SerializeToString,
                response_deserializer=cosmos_dot_bank_dot_v1beta1_dot_tx__pb2.MsgMultiSendResponse.FromString,
                _registered_method=True)
        self.UpdateParams = channel.unary_unary(
                '/cosmos.bank.v1beta1.Msg/UpdateParams',
                request_serializer=cosmos_dot_bank_dot_v1beta1_dot_tx__pb2.MsgUpdateParams.SerializeToString,
                response_deserializer=cosmos_dot_bank_dot_v1beta1_dot_tx__pb2.MsgUpdateParamsResponse.FromString,
                _registered_method=True)
        self.SetSendEnabled = channel.unary_unary(
                '/cosmos.bank.v1beta1.Msg/SetSendEnabled',
                request_serializer=cosmos_dot_bank_dot_v1beta1_dot_tx__pb2.MsgSetSendEnabled.SerializeToString,
                response_deserializer=cosmos_dot_bank_dot_v1beta1_dot_tx__pb2.MsgSetSendEnabledResponse.FromString,
                _registered_method=True)


class MsgServicer(object):
    """Msg defines the bank Msg service.
    """

    def Send(self, request, context):
        """Send defines a method for sending coins from one account to another account.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MultiSend(self, request, context):
        """MultiSend defines a method for sending coins from some accounts to other accounts.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateParams(self, request, context):
        """UpdateParams defines a governance operation for updating the x/bank module parameters.
        The authority is defined in the keeper.

        Since: cosmos-sdk 0.47
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetSendEnabled(self, request, context):
        """SetSendEnabled is a governance operation for setting the SendEnabled flag
        on any number of Denoms. Only the entries to add or update should be
        included. Entries that already exist in the store, but that aren't
        included in this message, will be left unchanged.

        Since: cosmos-sdk 0.47
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Send': grpc.unary_unary_rpc_method_handler(
                    servicer.Send,
                    request_deserializer=cosmos_dot_bank_dot_v1beta1_dot_tx__pb2.MsgSend.FromString,
                    response_serializer=cosmos_dot_bank_dot_v1beta1_dot_tx__pb2.MsgSendResponse.SerializeToString,
            ),
            'MultiSend': grpc.unary_unary_rpc_method_handler(
                    servicer.MultiSend,
                    request_deserializer=cosmos_dot_bank_dot_v1beta1_dot_tx__pb2.MsgMultiSend.FromString,
                    response_serializer=cosmos_dot_bank_dot_v1beta1_dot_tx__pb2.MsgMultiSendResponse.SerializeToString,
            ),
            'UpdateParams': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateParams,
                    request_deserializer=cosmos_dot_bank_dot_v1beta1_dot_tx__pb2.MsgUpdateParams.FromString,
                    response_serializer=cosmos_dot_bank_dot_v1beta1_dot_tx__pb2.MsgUpdateParamsResponse.SerializeToString,
            ),
            'SetSendEnabled': grpc.unary_unary_rpc_method_handler(
                    servicer.SetSendEnabled,
                    request_deserializer=cosmos_dot_bank_dot_v1beta1_dot_tx__pb2.MsgSetSendEnabled.FromString,
                    response_serializer=cosmos_dot_bank_dot_v1beta1_dot_tx__pb2.MsgSetSendEnabledResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cosmos.bank.v1beta1.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('cosmos.bank.v1beta1.Msg', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the bank Msg service.
    """

    @staticmethod
    def Send(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.bank.v1beta1.Msg/Send',
            cosmos_dot_bank_dot_v1beta1_dot_tx__pb2.MsgSend.SerializeToString,
            cosmos_dot_bank_dot_v1beta1_dot_tx__pb2.MsgSendResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def MultiSend(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.bank.v1beta1.Msg/MultiSend',
            cosmos_dot_bank_dot_v1beta1_dot_tx__pb2.MsgMultiSend.SerializeToString,
            cosmos_dot_bank_dot_v1beta1_dot_tx__pb2.MsgMultiSendResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.bank.v1beta1.Msg/UpdateParams',
            cosmos_dot_bank_dot_v1beta1_dot_tx__pb2.MsgUpdateParams.SerializeToString,
            cosmos_dot_bank_dot_v1beta1_dot_tx__pb2.MsgUpdateParamsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetSendEnabled(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.bank.v1beta1.Msg/SetSendEnabled',
            cosmos_dot_bank_dot_v1beta1_dot_tx__pb2.MsgSetSendEnabled.SerializeToString,
            cosmos_dot_bank_dot_v1beta1_dot_tx__pb2.MsgSetSendEnabledResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/listing/query.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/listing/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.dydxprotocol.listing import params_pb2 as dydxprotocol_dot_listing_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n dydxprotocol/listing/query.proto\x12\x14\x64ydxprotocol.listing\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a!dydxprotocol/listing/params.proto\"\x15\n\x13QueryMarketsHardCap\"/\n\x1bQueryMarketsHardCapResponse\x12\x10\n\x08hard_cap\x18\x01 \x01(\r\" \n\x1eQueryListingVaultDepositParams\"o\n&QueryListingVaultDepositParamsResponse\x12\x45\n\x06params\x18\x01 \x01(\x0b\x32/.dydxprotocol.listing.ListingVaultDepositParamsB\x04\xc8\xde\x1f\x00\x32\xee\x02\n\x05Query\x12\x9e\x01\n\x0eMarketsHardCap\x12).dydxprotocol.listing.QueryMarketsHardCap\x1a\x31.dydxprotocol.listing.QueryMarketsHardCapResponse\".\x82\xd3\xe4\x93\x02(\x12&/dydxprotocol/listing/markets_hard_cap\x12\xc3\x01\n\x19ListingVaultDepositParams\x12\x34.dydxprotocol.listing.QueryListingVaultDepositParams\x1a<.dydxprotocol.listing.QueryListingVaultDepositParamsResponse\"2\x82\xd3\xe4\x93\x02,\x12*/dydxprotocol/listing/vault_deposit_paramsB;Z9github.com/dydxprotocol/v4-chain/protocol/x/listing/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.listing.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z9github.com/dydxprotocol/v4-chain/protocol/x/listing/types'
  _globals['_QUERYLISTINGVAULTDEPOSITPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYLISTINGVAULTDEPOSITPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['MarketsHardCap']._loaded_options = None
  _globals['_QUERY'].methods_by_name['MarketsHardCap']._serialized_options = b'\202\323\344\223\002(\022&/dydxprotocol/listing/markets_hard_cap'
  _globals['_QUERY'].methods_by_name['ListingVaultDepositParams']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ListingVaultDepositParams']._serialized_options = b'\202\323\344\223\002,\022*/dydxprotocol/listing/vault_deposit_params'
  _globals['_QUERYMARKETSHARDCAP']._serialized_start=145
  _globals['_QUERYMARKETSHARDCAP']._serialized_end=166
  _globals['_QUERYMARKETSHARDCAPRESPONSE']._serialized_start=168
  _globals['_QUERYMARKETSHARDCAPRESPONSE']._serialized_end=215
  _globals['_QUERYLISTINGVAULTDEPOSITPARAMS']._serialized_start=217
  _globals['_QUERYLISTINGVAULTDEPOSITPARAMS']._serialized_end=249
  _globals['_QUERYLISTINGVAULTDEPOSITPARAMSRESPONSE']._serialized_start=251
  _globals['_QUERYLISTINGVAULTDEPOSITPARAMSRESPONSE']._serialized_end=362
  _globals['_QUERY']._serialized_start=365
  _globals['_QUERY']._serialized_end=731
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class VaultType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    VAULT_TYPE_UNSPECIFIED: _ClassVar[VaultType]
    VAULT_TYPE_CLOB: _ClassVar[VaultType]

class VaultStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    VAULT_STATUS_UNSPECIFIED: _ClassVar[VaultStatus]
    VAULT_STATUS_DEACTIVATED: _ClassVar[VaultStatus]
    VAULT_STATUS_STAND_BY: _ClassVar[VaultStatus]
    VAULT_STATUS_QUOTING: _ClassVar[VaultStatus]
    VAULT_STATUS_CLOSE_ONLY: _ClassVar[VaultStatus]
VAULT_TYPE_UNSPECIFIED: VaultType
VAULT_TYPE_CLOB: VaultType
VAULT_STATUS_UNSPECIFIED: VaultStatus
VAULT_STATUS_DEACTIVATED: VaultStatus
VAULT_STATUS_STAND_BY: VaultStatus
VAULT_STATUS_QUOTING: VaultStatus
VAULT_STATUS_CLOSE_ONLY: VaultStatus

class VaultId(_message.Message):
    __slots__ = ("type", "number")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    NUMBER_FIELD_NUMBER: _ClassVar[int]
    type: VaultType
    number: int
    def __init__(self, type: _Optional[_Union[VaultType, str]] = ..., number: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/upgrade/v1beta1/upgrade.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cosmos/upgrade/v1beta1/upgrade.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$cosmos/upgrade/v1beta1/upgrade.proto\x12\x16\x63osmos.upgrade.v1beta1\x1a\x19google/protobuf/any.proto\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x11\x61mino/amino.proto\"\xc0\x01\n\x04Plan\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x39\n\x04time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x0f\x18\x01\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xa8\xe7\xb0*\x01\x12\x0e\n\x06height\x18\x03 \x01(\x03\x12\x0c\n\x04info\x18\x04 \x01(\t\x12\x37\n\x15upgraded_client_state\x18\x05 \x01(\x0b\x32\x14.google.protobuf.AnyB\x02\x18\x01:\x18\xe8\xa0\x1f\x01\x8a\xe7\xb0*\x0f\x63osmos-sdk/Plan\"\xc1\x01\n\x17SoftwareUpgradeProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x35\n\x04plan\x18\x03 \x01(\x0b\x32\x1c.cosmos.upgrade.v1beta1.PlanB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:K\x18\x01\xe8\xa0\x1f\x01\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\x8a\xe7\xb0*\"cosmos-sdk/SoftwareUpgradeProposal\"\x96\x01\n\x1d\x43\x61ncelSoftwareUpgradeProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t:Q\x18\x01\xe8\xa0\x1f\x01\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\x8a\xe7\xb0*(cosmos-sdk/CancelSoftwareUpgradeProposal\"4\n\rModuleVersion\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x04:\x04\xe8\xa0\x1f\x01\x42\"Z\x1c\x63osmossdk.io/x/upgrade/types\xc8\xe1\x1e\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.upgrade.v1beta1.upgrade_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\034cosmossdk.io/x/upgrade/types\310\341\036\000'
  _globals['_PLAN'].fields_by_name['time']._loaded_options = None
  _globals['_PLAN'].fields_by_name['time']._serialized_options = b'\030\001\310\336\037\000\220\337\037\001\250\347\260*\001'
  _globals['_PLAN'].fields_by_name['upgraded_client_state']._loaded_options = None
  _globals['_PLAN'].fields_by_name['upgraded_client_state']._serialized_options = b'\030\001'
  _globals['_PLAN']._loaded_options = None
  _globals['_PLAN']._serialized_options = b'\350\240\037\001\212\347\260*\017cosmos-sdk/Plan'
  _globals['_SOFTWAREUPGRADEPROPOSAL'].fields_by_name['plan']._loaded_options = None
  _globals['_SOFTWAREUPGRADEPROPOSAL'].fields_by_name['plan']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_SOFTWAREUPGRADEPROPOSAL']._loaded_options = None
  _globals['_SOFTWAREUPGRADEPROPOSAL']._serialized_options = b'\030\001\350\240\037\001\312\264-\032cosmos.gov.v1beta1.Content\212\347\260*\"cosmos-sdk/SoftwareUpgradeProposal'
  _globals['_CANCELSOFTWAREUPGRADEPROPOSAL']._loaded_options = None
  _globals['_CANCELSOFTWAREUPGRADEPROPOSAL']._serialized_options = b'\030\001\350\240\037\001\312\264-\032cosmos.gov.v1beta1.Content\212\347\260*(cosmos-sdk/CancelSoftwareUpgradeProposal'
  _globals['_MODULEVERSION']._loaded_options = None
  _globals['_MODULEVERSION']._serialized_options = b'\350\240\037\001'
  _globals['_PLAN']._serialized_start=193
  _globals['_PLAN']._serialized_end=385
  _globals['_SOFTWAREUPGRADEPROPOSAL']._serialized_start=388
  _globals['_SOFTWAREUPGRADEPROPOSAL']._serialized_end=581
  _globals['_CANCELSOFTWAREUPGRADEPROPOSAL']._serialized_start=584
  _globals['_CANCELSOFTWAREUPGRADEPROPOSAL']._serialized_end=734
  _globals['_MODULEVERSION']._serialized_start=736
  _globals['_MODULEVERSION']._serialized_end=788
# @@protoc_insertion_point(module_scope)



from v4_proto.cosmos.app.v1alpha1 import module_pb2 as _module_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Module(_message.Message):
    __slots__ = ("hooks_order", "authority", "bech32_prefix_validator", "bech32_prefix_consensus")
    HOOKS_ORDER_FIELD_NUMBER: _ClassVar[int]
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    BECH32_PREFIX_VALIDATOR_FIELD_NUMBER: _ClassVar[int]
    BECH32_PREFIX_CONSENSUS_FIELD_NUMBER: _ClassVar[int]
    hooks_order: _containers.RepeatedScalarFieldContainer[str]
    authority: str
    bech32_prefix_validator: str
    bech32_prefix_consensus: str
    def __init__(self, hooks_order: _Optional[_Iterable[str]] = ..., authority: _Optional[str] = ..., bech32_prefix_validator: _Optional[str] = ..., bech32_prefix_consensus: _Optional[str] = ...) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Pairs(_message.Message):
    __slots__ = ("pairs",)
    PAIRS_FIELD_NUMBER: _ClassVar[int]
    pairs: _containers.RepeatedCompositeFieldContainer[Pair]
    def __init__(self, pairs: _Optional[_Iterable[_Union[Pair, _Mapping]]] = ...) -> None: ...

class Pair(_message.Message):
    __slots__ = ("key", "value")
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    key: bytes
    value: bytes
    def __init__(self, key: _Optional[bytes] = ..., value: _Optional[bytes] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/indexer/protocol/v1/perpetual.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/indexer/protocol/v1/perpetual.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0dydxprotocol/indexer/protocol/v1/perpetual.proto\x12 dydxprotocol.indexer.protocol.v1*\x81\x01\n\x13PerpetualMarketType\x12%\n!PERPETUAL_MARKET_TYPE_UNSPECIFIED\x10\x00\x12\x1f\n\x1bPERPETUAL_MARKET_TYPE_CROSS\x10\x01\x12\"\n\x1ePERPETUAL_MARKET_TYPE_ISOLATED\x10\x02\x42\x45ZCgithub.com/dydxprotocol/v4-chain/protocol/indexer/protocol/v1/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.indexer.protocol.v1.perpetual_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZCgithub.com/dydxprotocol/v4-chain/protocol/indexer/protocol/v1/types'
  _globals['_PERPETUALMARKETTYPE']._serialized_start=87
  _globals['_PERPETUALMARKETTYPE']._serialized_end=216
# @@protoc_insertion_point(module_scope)



import datetime

from google.protobuf import timestamp_pb2 as _timestamp_pb2
from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class VestEntry(_message.Message):
    __slots__ = ("vester_account", "treasury_account", "denom", "start_time", "end_time")
    VESTER_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    TREASURY_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    DENOM_FIELD_NUMBER: _ClassVar[int]
    START_TIME_FIELD_NUMBER: _ClassVar[int]
    END_TIME_FIELD_NUMBER: _ClassVar[int]
    vester_account: str
    treasury_account: str
    denom: str
    start_time: _timestamp_pb2.Timestamp
    end_time: _timestamp_pb2.Timestamp
    def __init__(self, vester_account: _Optional[str] = ..., treasury_account: _Optional[str] = ..., denom: _Optional[str] = ..., start_time: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., end_time: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/gov/v1beta1/genesis.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cosmos/gov/v1beta1/genesis.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.cosmos.gov.v1beta1 import gov_pb2 as cosmos_dot_gov_dot_v1beta1_dot_gov__pb2
from v4_proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n cosmos/gov/v1beta1/genesis.proto\x12\x12\x63osmos.gov.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1c\x63osmos/gov/v1beta1/gov.proto\x1a\x11\x61mino/amino.proto\"\xc4\x03\n\x0cGenesisState\x12\x1c\n\x14starting_proposal_id\x18\x01 \x01(\x04\x12\x44\n\x08\x64\x65posits\x18\x02 \x03(\x0b\x32\x1b.cosmos.gov.v1beta1.DepositB\x15\xc8\xde\x1f\x00\xaa\xdf\x1f\x08\x44\x65posits\xa8\xe7\xb0*\x01\x12;\n\x05votes\x18\x03 \x03(\x0b\x32\x18.cosmos.gov.v1beta1.VoteB\x12\xc8\xde\x1f\x00\xaa\xdf\x1f\x05Votes\xa8\xe7\xb0*\x01\x12G\n\tproposals\x18\x04 \x03(\x0b\x32\x1c.cosmos.gov.v1beta1.ProposalB\x16\xc8\xde\x1f\x00\xaa\xdf\x1f\tProposals\xa8\xe7\xb0*\x01\x12\x44\n\x0e\x64\x65posit_params\x18\x05 \x01(\x0b\x32!.cosmos.gov.v1beta1.DepositParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12\x42\n\rvoting_params\x18\x06 \x01(\x0b\x32 .cosmos.gov.v1beta1.VotingParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12@\n\x0ctally_params\x18\x07 \x01(\x0b\x32\x1f.cosmos.gov.v1beta1.TallyParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x42\x32Z0github.com/cosmos/cosmos-sdk/x/gov/types/v1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.gov.v1beta1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z0github.com/cosmos/cosmos-sdk/x/gov/types/v1beta1'
  _globals['_GENESISSTATE'].fields_by_name['deposits']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['deposits']._serialized_options = b'\310\336\037\000\252\337\037\010Deposits\250\347\260*\001'
  _globals['_GENESISSTATE'].fields_by_name['votes']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['votes']._serialized_options = b'\310\336\037\000\252\337\037\005Votes\250\347\260*\001'
  _globals['_GENESISSTATE'].fields_by_name['proposals']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['proposals']._serialized_options = b'\310\336\037\000\252\337\037\tProposals\250\347\260*\001'
  _globals['_GENESISSTATE'].fields_by_name['deposit_params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['deposit_params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_GENESISSTATE'].fields_by_name['voting_params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['voting_params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_GENESISSTATE'].fields_by_name['tally_params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['tally_params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_GENESISSTATE']._serialized_start=128
  _globals['_GENESISSTATE']._serialized_end=580
# @@protoc_insertion_point(module_scope)



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.google.api import annotations_pb2 as _annotations_pb2
from v4_proto.dydxprotocol.accountplus import accountplus_pb2 as _accountplus_pb2
from v4_proto.dydxprotocol.accountplus import models_pb2 as _models_pb2
from v4_proto.dydxprotocol.accountplus import params_pb2 as _params_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AccountStateRequest(_message.Message):
    __slots__ = ("address",)
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    address: str
    def __init__(self, address: _Optional[str] = ...) -> None: ...

class AccountStateResponse(_message.Message):
    __slots__ = ("account_state",)
    ACCOUNT_STATE_FIELD_NUMBER: _ClassVar[int]
    account_state: _accountplus_pb2.AccountState
    def __init__(self, account_state: _Optional[_Union[_accountplus_pb2.AccountState, _Mapping]] = ...) -> None: ...

class QueryParamsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryParamsResponse(_message.Message):
    __slots__ = ("params",)
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    params: _params_pb2.Params
    def __init__(self, params: _Optional[_Union[_params_pb2.Params, _Mapping]] = ...) -> None: ...

class GetAuthenticatorsRequest(_message.Message):
    __slots__ = ("account",)
    ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    account: str
    def __init__(self, account: _Optional[str] = ...) -> None: ...

class GetAuthenticatorsResponse(_message.Message):
    __slots__ = ("account_authenticators",)
    ACCOUNT_AUTHENTICATORS_FIELD_NUMBER: _ClassVar[int]
    account_authenticators: _containers.RepeatedCompositeFieldContainer[_models_pb2.AccountAuthenticator]
    def __init__(self, account_authenticators: _Optional[_Iterable[_Union[_models_pb2.AccountAuthenticator, _Mapping]]] = ...) -> None: ...

class GetAuthenticatorRequest(_message.Message):
    __slots__ = ("account", "authenticator_id")
    ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    AUTHENTICATOR_ID_FIELD_NUMBER: _ClassVar[int]
    account: str
    authenticator_id: int
    def __init__(self, account: _Optional[str] = ..., authenticator_id: _Optional[int] = ...) -> None: ...

class GetAuthenticatorResponse(_message.Message):
    __slots__ = ("account_authenticator",)
    ACCOUNT_AUTHENTICATOR_FIELD_NUMBER: _ClassVar[int]
    account_authenticator: _models_pb2.AccountAuthenticator
    def __init__(self, account_authenticator: _Optional[_Union[_models_pb2.AccountAuthenticator, _Mapping]] = ...) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Params(_message.Message):
    __slots__ = ("is_smart_account_active",)
    IS_SMART_ACCOUNT_ACTIVE_FIELD_NUMBER: _ClassVar[int]
    is_smart_account_active: bool
    def __init__(self, is_smart_account_active: bool = ...) -> None: ...



from v4_proto.amino import amino_pb2 as _amino_pb2
from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.cosmos.crypto.multisig.v1beta1 import multisig_pb2 as _multisig_pb2
from v4_proto.cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from v4_proto.cosmos.tx.signing.v1beta1 import signing_pb2 as _signing_pb2
from google.protobuf import any_pb2 as _any_pb2
from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Tx(_message.Message):
    __slots__ = ("body", "auth_info", "signatures")
    BODY_FIELD_NUMBER: _ClassVar[int]
    AUTH_INFO_FIELD_NUMBER: _ClassVar[int]
    SIGNATURES_FIELD_NUMBER: _ClassVar[int]
    body: TxBody
    auth_info: AuthInfo
    signatures: _containers.RepeatedScalarFieldContainer[bytes]
    def __init__(self, body: _Optional[_Union[TxBody, _Mapping]] = ..., auth_info: _Optional[_Union[AuthInfo, _Mapping]] = ..., signatures: _Optional[_Iterable[bytes]] = ...) -> None: ...

class TxRaw(_message.Message):
    __slots__ = ("body_bytes", "auth_info_bytes", "signatures")
    BODY_BYTES_FIELD_NUMBER: _ClassVar[int]
    AUTH_INFO_BYTES_FIELD_NUMBER: _ClassVar[int]
    SIGNATURES_FIELD_NUMBER: _ClassVar[int]
    body_bytes: bytes
    auth_info_bytes: bytes
    signatures: _containers.RepeatedScalarFieldContainer[bytes]
    def __init__(self, body_bytes: _Optional[bytes] = ..., auth_info_bytes: _Optional[bytes] = ..., signatures: _Optional[_Iterable[bytes]] = ...) -> None: ...

class SignDoc(_message.Message):
    __slots__ = ("body_bytes", "auth_info_bytes", "chain_id", "account_number")
    BODY_BYTES_FIELD_NUMBER: _ClassVar[int]
    AUTH_INFO_BYTES_FIELD_NUMBER: _ClassVar[int]
    CHAIN_ID_FIELD_NUMBER: _ClassVar[int]
    ACCOUNT_NUMBER_FIELD_NUMBER: _ClassVar[int]
    body_bytes: bytes
    auth_info_bytes: bytes
    chain_id: str
    account_number: int
    def __init__(self, body_bytes: _Optional[bytes] = ..., auth_info_bytes: _Optional[bytes] = ..., chain_id: _Optional[str] = ..., account_number: _Optional[int] = ...) -> None: ...

class SignDocDirectAux(_message.Message):
    __slots__ = ("body_bytes", "public_key", "chain_id", "account_number", "sequence", "tip")
    BODY_BYTES_FIELD_NUMBER: _ClassVar[int]
    PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    CHAIN_ID_FIELD_NUMBER: _ClassVar[int]
    ACCOUNT_NUMBER_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    TIP_FIELD_NUMBER: _ClassVar[int]
    body_bytes: bytes
    public_key: _any_pb2.Any
    chain_id: str
    account_number: int
    sequence: int
    tip: Tip
    def __init__(self, body_bytes: _Optional[bytes] = ..., public_key: _Optional[_Union[_any_pb2.Any, _Mapping]] = ..., chain_id: _Optional[str] = ..., account_number: _Optional[int] = ..., sequence: _Optional[int] = ..., tip: _Optional[_Union[Tip, _Mapping]] = ...) -> None: ...

class TxBody(_message.Message):
    __slots__ = ("messages", "memo", "timeout_height", "extension_options", "non_critical_extension_options")
    MESSAGES_FIELD_NUMBER: _ClassVar[int]
    MEMO_FIELD_NUMBER: _ClassVar[int]
    TIMEOUT_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    EXTENSION_OPTIONS_FIELD_NUMBER: _ClassVar[int]
    NON_CRITICAL_EXTENSION_OPTIONS_FIELD_NUMBER: _ClassVar[int]
    messages: _containers.RepeatedCompositeFieldContainer[_any_pb2.Any]
    memo: str
    timeout_height: int
    extension_options: _containers.RepeatedCompositeFieldContainer[_any_pb2.Any]
    non_critical_extension_options: _containers.RepeatedCompositeFieldContainer[_any_pb2.Any]
    def __init__(self, messages: _Optional[_Iterable[_Union[_any_pb2.Any, _Mapping]]] = ..., memo: _Optional[str] = ..., timeout_height: _Optional[int] = ..., extension_options: _Optional[_Iterable[_Union[_any_pb2.Any, _Mapping]]] = ..., non_critical_extension_options: _Optional[_Iterable[_Union[_any_pb2.Any, _Mapping]]] = ...) -> None: ...

class AuthInfo(_message.Message):
    __slots__ = ("signer_infos", "fee", "tip")
    SIGNER_INFOS_FIELD_NUMBER: _ClassVar[int]
    FEE_FIELD_NUMBER: _ClassVar[int]
    TIP_FIELD_NUMBER: _ClassVar[int]
    signer_infos: _containers.RepeatedCompositeFieldContainer[SignerInfo]
    fee: Fee
    tip: Tip
    def __init__(self, signer_infos: _Optional[_Iterable[_Union[SignerInfo, _Mapping]]] = ..., fee: _Optional[_Union[Fee, _Mapping]] = ..., tip: _Optional[_Union[Tip, _Mapping]] = ...) -> None: ...

class SignerInfo(_message.Message):
    __slots__ = ("public_key", "mode_info", "sequence")
    PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    MODE_INFO_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    public_key: _any_pb2.Any
    mode_info: ModeInfo
    sequence: int
    def __init__(self, public_key: _Optional[_Union[_any_pb2.Any, _Mapping]] = ..., mode_info: _Optional[_Union[ModeInfo, _Mapping]] = ..., sequence: _Optional[int] = ...) -> None: ...

class ModeInfo(_message.Message):
    __slots__ = ("single", "multi")
    class Single(_message.Message):
        __slots__ = ("mode",)
        MODE_FIELD_NUMBER: _ClassVar[int]
        mode: _signing_pb2.SignMode
        def __init__(self, mode: _Optional[_Union[_signing_pb2.SignMode, str]] = ...) -> None: ...
    class Multi(_message.Message):
        __slots__ = ("bitarray", "mode_infos")
        BITARRAY_FIELD_NUMBER: _ClassVar[int]
        MODE_INFOS_FIELD_NUMBER: _ClassVar[int]
        bitarray: _multisig_pb2.CompactBitArray
        mode_infos: _containers.RepeatedCompositeFieldContainer[ModeInfo]
        def __init__(self, bitarray: _Optional[_Union[_multisig_pb2.CompactBitArray, _Mapping]] = ..., mode_infos: _Optional[_Iterable[_Union[ModeInfo, _Mapping]]] = ...) -> None: ...
    SINGLE_FIELD_NUMBER: _ClassVar[int]
    MULTI_FIELD_NUMBER: _ClassVar[int]
    single: ModeInfo.Single
    multi: ModeInfo.Multi
    def __init__(self, single: _Optional[_Union[ModeInfo.Single, _Mapping]] = ..., multi: _Optional[_Union[ModeInfo.Multi, _Mapping]] = ...) -> None: ...

class Fee(_message.Message):
    __slots__ = ("amount", "gas_limit", "payer", "granter")
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    GAS_LIMIT_FIELD_NUMBER: _ClassVar[int]
    PAYER_FIELD_NUMBER: _ClassVar[int]
    GRANTER_FIELD_NUMBER: _ClassVar[int]
    amount: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    gas_limit: int
    payer: str
    granter: str
    def __init__(self, amount: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ..., gas_limit: _Optional[int] = ..., payer: _Optional[str] = ..., granter: _Optional[str] = ...) -> None: ...

class Tip(_message.Message):
    __slots__ = ("amount", "tipper")
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    TIPPER_FIELD_NUMBER: _ClassVar[int]
    amount: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    tipper: str
    def __init__(self, amount: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ..., tipper: _Optional[str] = ...) -> None: ...

class AuxSignerData(_message.Message):
    __slots__ = ("address", "sign_doc", "mode", "sig")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    SIGN_DOC_FIELD_NUMBER: _ClassVar[int]
    MODE_FIELD_NUMBER: _ClassVar[int]
    SIG_FIELD_NUMBER: _ClassVar[int]
    address: str
    sign_doc: SignDocDirectAux
    mode: _signing_pb2.SignMode
    sig: bytes
    def __init__(self, address: _Optional[str] = ..., sign_doc: _Optional[_Union[SignDocDirectAux, _Mapping]] = ..., mode: _Optional[_Union[_signing_pb2.SignMode, str]] = ..., sig: _Optional[bytes] = ...) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.cosmos.vesting.v1beta1 import vesting_pb2 as _vesting_pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as _msg_pb2
from v4_proto.amino import amino_pb2 as _amino_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MsgCreateVestingAccount(_message.Message):
    __slots__ = ("from_address", "to_address", "amount", "end_time", "delayed")
    FROM_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    TO_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    END_TIME_FIELD_NUMBER: _ClassVar[int]
    DELAYED_FIELD_NUMBER: _ClassVar[int]
    from_address: str
    to_address: str
    amount: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    end_time: int
    delayed: bool
    def __init__(self, from_address: _Optional[str] = ..., to_address: _Optional[str] = ..., amount: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ..., end_time: _Optional[int] = ..., delayed: bool = ...) -> None: ...

class MsgCreateVestingAccountResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgCreatePermanentLockedAccount(_message.Message):
    __slots__ = ("from_address", "to_address", "amount")
    FROM_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    TO_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    from_address: str
    to_address: str
    amount: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    def __init__(self, from_address: _Optional[str] = ..., to_address: _Optional[str] = ..., amount: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ...) -> None: ...

class MsgCreatePermanentLockedAccountResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgCreatePeriodicVestingAccount(_message.Message):
    __slots__ = ("from_address", "to_address", "start_time", "vesting_periods")
    FROM_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    TO_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    START_TIME_FIELD_NUMBER: _ClassVar[int]
    VESTING_PERIODS_FIELD_NUMBER: _ClassVar[int]
    from_address: str
    to_address: str
    start_time: int
    vesting_periods: _containers.RepeatedCompositeFieldContainer[_vesting_pb2.Period]
    def __init__(self, from_address: _Optional[str] = ..., to_address: _Optional[str] = ..., start_time: _Optional[int] = ..., vesting_periods: _Optional[_Iterable[_Union[_vesting_pb2.Period, _Mapping]]] = ...) -> None: ...

class MsgCreatePeriodicVestingAccountResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



import datetime

from google.protobuf import any_pb2 as _any_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from v4_proto.cosmos.staking.v1beta1 import staking_pb2 as _staking_pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as _msg_pb2
from v4_proto.amino import amino_pb2 as _amino_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MsgCreateValidator(_message.Message):
    __slots__ = ("description", "commission", "min_self_delegation", "delegator_address", "validator_address", "pubkey", "value")
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    COMMISSION_FIELD_NUMBER: _ClassVar[int]
    MIN_SELF_DELEGATION_FIELD_NUMBER: _ClassVar[int]
    DELEGATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PUBKEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    description: _staking_pb2.Description
    commission: _staking_pb2.CommissionRates
    min_self_delegation: str
    delegator_address: str
    validator_address: str
    pubkey: _any_pb2.Any
    value: _coin_pb2.Coin
    def __init__(self, description: _Optional[_Union[_staking_pb2.Description, _Mapping]] = ..., commission: _Optional[_Union[_staking_pb2.CommissionRates, _Mapping]] = ..., min_self_delegation: _Optional[str] = ..., delegator_address: _Optional[str] = ..., validator_address: _Optional[str] = ..., pubkey: _Optional[_Union[_any_pb2.Any, _Mapping]] = ..., value: _Optional[_Union[_coin_pb2.Coin, _Mapping]] = ...) -> None: ...

class MsgCreateValidatorResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgEditValidator(_message.Message):
    __slots__ = ("description", "validator_address", "commission_rate", "min_self_delegation")
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    COMMISSION_RATE_FIELD_NUMBER: _ClassVar[int]
    MIN_SELF_DELEGATION_FIELD_NUMBER: _ClassVar[int]
    description: _staking_pb2.Description
    validator_address: str
    commission_rate: str
    min_self_delegation: str
    def __init__(self, description: _Optional[_Union[_staking_pb2.Description, _Mapping]] = ..., validator_address: _Optional[str] = ..., commission_rate: _Optional[str] = ..., min_self_delegation: _Optional[str] = ...) -> None: ...

class MsgEditValidatorResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgDelegate(_message.Message):
    __slots__ = ("delegator_address", "validator_address", "amount")
    DELEGATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    delegator_address: str
    validator_address: str
    amount: _coin_pb2.Coin
    def __init__(self, delegator_address: _Optional[str] = ..., validator_address: _Optional[str] = ..., amount: _Optional[_Union[_coin_pb2.Coin, _Mapping]] = ...) -> None: ...

class MsgDelegateResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgBeginRedelegate(_message.Message):
    __slots__ = ("delegator_address", "validator_src_address", "validator_dst_address", "amount")
    DELEGATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_SRC_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_DST_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    delegator_address: str
    validator_src_address: str
    validator_dst_address: str
    amount: _coin_pb2.Coin
    def __init__(self, delegator_address: _Optional[str] = ..., validator_src_address: _Optional[str] = ..., validator_dst_address: _Optional[str] = ..., amount: _Optional[_Union[_coin_pb2.Coin, _Mapping]] = ...) -> None: ...

class MsgBeginRedelegateResponse(_message.Message):
    __slots__ = ("completion_time",)
    COMPLETION_TIME_FIELD_NUMBER: _ClassVar[int]
    completion_time: _timestamp_pb2.Timestamp
    def __init__(self, completion_time: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class MsgUndelegate(_message.Message):
    __slots__ = ("delegator_address", "validator_address", "amount")
    DELEGATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    delegator_address: str
    validator_address: str
    amount: _coin_pb2.Coin
    def __init__(self, delegator_address: _Optional[str] = ..., validator_address: _Optional[str] = ..., amount: _Optional[_Union[_coin_pb2.Coin, _Mapping]] = ...) -> None: ...

class MsgUndelegateResponse(_message.Message):
    __slots__ = ("completion_time", "amount")
    COMPLETION_TIME_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    completion_time: _timestamp_pb2.Timestamp
    amount: _coin_pb2.Coin
    def __init__(self, completion_time: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., amount: _Optional[_Union[_coin_pb2.Coin, _Mapping]] = ...) -> None: ...

class MsgCancelUnbondingDelegation(_message.Message):
    __slots__ = ("delegator_address", "validator_address", "amount", "creation_height")
    DELEGATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    CREATION_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    delegator_address: str
    validator_address: str
    amount: _coin_pb2.Coin
    creation_height: int
    def __init__(self, delegator_address: _Optional[str] = ..., validator_address: _Optional[str] = ..., amount: _Optional[_Union[_coin_pb2.Coin, _Mapping]] = ..., creation_height: _Optional[int] = ...) -> None: ...

class MsgCancelUnbondingDelegationResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgUpdateParams(_message.Message):
    __slots__ = ("authority", "params")
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    authority: str
    params: _staking_pb2.Params
    def __init__(self, authority: _Optional[str] = ..., params: _Optional[_Union[_staking_pb2.Params, _Mapping]] = ...) -> None: ...

class MsgUpdateParamsResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.cosmos.mint.v1beta1 import mint_pb2 as _mint_pb2
from v4_proto.amino import amino_pb2 as _amino_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ("minter", "params")
    MINTER_FIELD_NUMBER: _ClassVar[int]
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    minter: _mint_pb2.Minter
    params: _mint_pb2.Params
    def __init__(self, minter: _Optional[_Union[_mint_pb2.Minter, _Mapping]] = ..., params: _Optional[_Union[_mint_pb2.Params, _Mapping]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from v4_proto.dydxprotocol.vault import tx_pb2 as dydxprotocol_dot_vault_dot_tx__pb2

GRPC_GENERATED_VERSION = '1.75.1'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in dydxprotocol/vault/tx_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class MsgStub(object):
    """Msg defines the Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DepositToMegavault = channel.unary_unary(
                '/dydxprotocol.vault.Msg/DepositToMegavault',
                request_serializer=dydxprotocol_dot_vault_dot_tx__pb2.MsgDepositToMegavault.SerializeToString,
                response_deserializer=dydxprotocol_dot_vault_dot_tx__pb2.MsgDepositToMegavaultResponse.FromString,
                _registered_method=True)
        self.WithdrawFromMegavault = channel.unary_unary(
                '/dydxprotocol.vault.Msg/WithdrawFromMegavault',
                request_serializer=dydxprotocol_dot_vault_dot_tx__pb2.MsgWithdrawFromMegavault.SerializeToString,
                response_deserializer=dydxprotocol_dot_vault_dot_tx__pb2.MsgWithdrawFromMegavaultResponse.FromString,
                _registered_method=True)
        self.UpdateDefaultQuotingParams = channel.unary_unary(
                '/dydxprotocol.vault.Msg/UpdateDefaultQuotingParams',
                request_serializer=dydxprotocol_dot_vault_dot_tx__pb2.MsgUpdateDefaultQuotingParams.SerializeToString,
                response_deserializer=dydxprotocol_dot_vault_dot_tx__pb2.MsgUpdateDefaultQuotingParamsResponse.FromString,
                _registered_method=True)
        self.UpdateOperatorParams = channel.unary_unary(
                '/dydxprotocol.vault.Msg/UpdateOperatorParams',
                request_serializer=dydxprotocol_dot_vault_dot_tx__pb2.MsgUpdateOperatorParams.SerializeToString,
                response_deserializer=dydxprotocol_dot_vault_dot_tx__pb2.MsgUpdateOperatorParamsResponse.FromString,
                _registered_method=True)
        self.SetVaultParams = channel.unary_unary(
                '/dydxprotocol.vault.Msg/SetVaultParams',
                request_serializer=dydxprotocol_dot_vault_dot_tx__pb2.MsgSetVaultParams.SerializeToString,
                response_deserializer=dydxprotocol_dot_vault_dot_tx__pb2.MsgSetVaultParamsResponse.FromString,
                _registered_method=True)
        self.UnlockShares = channel.unary_unary(
                '/dydxprotocol.vault.Msg/UnlockShares',
                request_serializer=dydxprotocol_dot_vault_dot_tx__pb2.MsgUnlockShares.SerializeToString,
                response_deserializer=dydxprotocol_dot_vault_dot_tx__pb2.MsgUnlockSharesResponse.FromString,
                _registered_method=True)
        self.AllocateToVault = channel.unary_unary(
                '/dydxprotocol.vault.Msg/AllocateToVault',
                request_serializer=dydxprotocol_dot_vault_dot_tx__pb2.MsgAllocateToVault.SerializeToString,
                response_deserializer=dydxprotocol_dot_vault_dot_tx__pb2.MsgAllocateToVaultResponse.FromString,
                _registered_method=True)
        self.RetrieveFromVault = channel.unary_unary(
                '/dydxprotocol.vault.Msg/RetrieveFromVault',
                request_serializer=dydxprotocol_dot_vault_dot_tx__pb2.MsgRetrieveFromVault.SerializeToString,
                response_deserializer=dydxprotocol_dot_vault_dot_tx__pb2.MsgRetrieveFromVaultResponse.FromString,
                _registered_method=True)


class MsgServicer(object):
    """Msg defines the Msg service.
    """

    def DepositToMegavault(self, request, context):
        """DepositToMegavault deposits funds into megavault.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WithdrawFromMegavault(self, request, context):
        """WithdrawFromMegavault withdraws shares from megavault.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDefaultQuotingParams(self, request, context):
        """UpdateDefaultQuotingParams updates the default quoting params in state.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateOperatorParams(self, request, context):
        """UpdateOperatorParams sets the parameters regarding megavault operator.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetVaultParams(self, request, context):
        """SetVaultParams sets the parameters of a specific vault.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnlockShares(self, request, context):
        """UnlockShares unlocks an owner's shares that are due to unlock by the block
        height that this transaction is included in.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AllocateToVault(self, request, context):
        """AllocateToVault allocates funds from main vault to a vault.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RetrieveFromVault(self, request, context):
        """RetrieveFromVault retrieves funds from a vault to main vault.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'DepositToMegavault': grpc.unary_unary_rpc_method_handler(
                    servicer.DepositToMegavault,
                    request_deserializer=dydxprotocol_dot_vault_dot_tx__pb2.MsgDepositToMegavault.FromString,
                    response_serializer=dydxprotocol_dot_vault_dot_tx__pb2.MsgDepositToMegavaultResponse.SerializeToString,
            ),
            'WithdrawFromMegavault': grpc.unary_unary_rpc_method_handler(
                    servicer.WithdrawFromMegavault,
                    request_deserializer=dydxprotocol_dot_vault_dot_tx__pb2.MsgWithdrawFromMegavault.FromString,
                    response_serializer=dydxprotocol_dot_vault_dot_tx__pb2.MsgWithdrawFromMegavaultResponse.SerializeToString,
            ),
            'UpdateDefaultQuotingParams': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDefaultQuotingParams,
                    request_deserializer=dydxprotocol_dot_vault_dot_tx__pb2.MsgUpdateDefaultQuotingParams.FromString,
                    response_serializer=dydxprotocol_dot_vault_dot_tx__pb2.MsgUpdateDefaultQuotingParamsResponse.SerializeToString,
            ),
            'UpdateOperatorParams': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateOperatorParams,
                    request_deserializer=dydxprotocol_dot_vault_dot_tx__pb2.MsgUpdateOperatorParams.FromString,
                    response_serializer=dydxprotocol_dot_vault_dot_tx__pb2.MsgUpdateOperatorParamsResponse.SerializeToString,
            ),
            'SetVaultParams': grpc.unary_unary_rpc_method_handler(
                    servicer.SetVaultParams,
                    request_deserializer=dydxprotocol_dot_vault_dot_tx__pb2.MsgSetVaultParams.FromString,
                    response_serializer=dydxprotocol_dot_vault_dot_tx__pb2.MsgSetVaultParamsResponse.SerializeToString,
            ),
            'UnlockShares': grpc.unary_unary_rpc_method_handler(
                    servicer.UnlockShares,
                    request_deserializer=dydxprotocol_dot_vault_dot_tx__pb2.MsgUnlockShares.FromString,
                    response_serializer=dydxprotocol_dot_vault_dot_tx__pb2.MsgUnlockSharesResponse.SerializeToString,
            ),
            'AllocateToVault': grpc.unary_unary_rpc_method_handler(
                    servicer.AllocateToVault,
                    request_deserializer=dydxprotocol_dot_vault_dot_tx__pb2.MsgAllocateToVault.FromString,
                    response_serializer=dydxprotocol_dot_vault_dot_tx__pb2.MsgAllocateToVaultResponse.SerializeToString,
            ),
            'RetrieveFromVault': grpc.unary_unary_rpc_method_handler(
                    servicer.RetrieveFromVault,
                    request_deserializer=dydxprotocol_dot_vault_dot_tx__pb2.MsgRetrieveFromVault.FromString,
                    response_serializer=dydxprotocol_dot_vault_dot_tx__pb2.MsgRetrieveFromVaultResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dydxprotocol.vault.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('dydxprotocol.vault.Msg', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the Msg service.
    """

    @staticmethod
    def DepositToMegavault(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.vault.Msg/DepositToMegavault',
            dydxprotocol_dot_vault_dot_tx__pb2.MsgDepositToMegavault.SerializeToString,
            dydxprotocol_dot_vault_dot_tx__pb2.MsgDepositToMegavaultResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def WithdrawFromMegavault(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.vault.Msg/WithdrawFromMegavault',
            dydxprotocol_dot_vault_dot_tx__pb2.MsgWithdrawFromMegavault.SerializeToString,
            dydxprotocol_dot_vault_dot_tx__pb2.MsgWithdrawFromMegavaultResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateDefaultQuotingParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.vault.Msg/UpdateDefaultQuotingParams',
            dydxprotocol_dot_vault_dot_tx__pb2.MsgUpdateDefaultQuotingParams.SerializeToString,
            dydxprotocol_dot_vault_dot_tx__pb2.MsgUpdateDefaultQuotingParamsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateOperatorParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.vault.Msg/UpdateOperatorParams',
            dydxprotocol_dot_vault_dot_tx__pb2.MsgUpdateOperatorParams.SerializeToString,
            dydxprotocol_dot_vault_dot_tx__pb2.MsgUpdateOperatorParamsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetVaultParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.vault.Msg/SetVaultParams',
            dydxprotocol_dot_vault_dot_tx__pb2.MsgSetVaultParams.SerializeToString,
            dydxprotocol_dot_vault_dot_tx__pb2.MsgSetVaultParamsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UnlockShares(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.vault.Msg/UnlockShares',
            dydxprotocol_dot_vault_dot_tx__pb2.MsgUnlockShares.SerializeToString,
            dydxprotocol_dot_vault_dot_tx__pb2.MsgUnlockSharesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AllocateToVault(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.vault.Msg/AllocateToVault',
            dydxprotocol_dot_vault_dot_tx__pb2.MsgAllocateToVault.SerializeToString,
            dydxprotocol_dot_vault_dot_tx__pb2.MsgAllocateToVaultResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RetrieveFromVault(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.vault.Msg/RetrieveFromVault',
            dydxprotocol_dot_vault_dot_tx__pb2.MsgRetrieveFromVault.SerializeToString,
            dydxprotocol_dot_vault_dot_tx__pb2.MsgRetrieveFromVaultResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/perpetuals/perpetual.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/perpetuals/perpetual.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'dydxprotocol/perpetuals/perpetual.proto\x12\x17\x64ydxprotocol.perpetuals\x1a\x14gogoproto/gogo.proto\"\x8d\x02\n\tPerpetual\x12>\n\x06params\x18\x01 \x01(\x0b\x32(.dydxprotocol.perpetuals.PerpetualParamsB\x04\xc8\xde\x1f\x00\x12_\n\rfunding_index\x18\x02 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\x12_\n\ropen_interest\x18\x03 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\"\xd3\x01\n\x0fPerpetualParams\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0e\n\x06ticker\x18\x02 \x01(\t\x12\x11\n\tmarket_id\x18\x03 \x01(\r\x12\x19\n\x11\x61tomic_resolution\x18\x04 \x01(\x11\x12\x1b\n\x13\x64\x65\x66\x61ult_funding_ppm\x18\x05 \x01(\x11\x12\x16\n\x0eliquidity_tier\x18\x06 \x01(\r\x12\x41\n\x0bmarket_type\x18\x07 \x01(\x0e\x32,.dydxprotocol.perpetuals.PerpetualMarketType\"8\n\x0eMarketPremiums\x12\x14\n\x0cperpetual_id\x18\x01 \x01(\r\x12\x10\n\x08premiums\x18\x02 \x03(\x11\"p\n\x0cPremiumStore\x12J\n\x13\x61ll_market_premiums\x18\x01 \x03(\x0b\x32\'.dydxprotocol.perpetuals.MarketPremiumsB\x04\xc8\xde\x1f\x00\x12\x14\n\x0cnum_premiums\x18\x02 \x01(\r\"\xe6\x01\n\rLiquidityTier\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1a\n\x12initial_margin_ppm\x18\x03 \x01(\r\x12 \n\x18maintenance_fraction_ppm\x18\x04 \x01(\r\x12\"\n\x16\x62\x61se_position_notional\x18\x05 \x01(\x04\x42\x02\x18\x01\x12\x17\n\x0fimpact_notional\x18\x06 \x01(\x04\x12\x1f\n\x17open_interest_lower_cap\x18\x07 \x01(\x04\x12\x1f\n\x17open_interest_upper_cap\x18\x08 \x01(\x04*\x81\x01\n\x13PerpetualMarketType\x12%\n!PERPETUAL_MARKET_TYPE_UNSPECIFIED\x10\x00\x12\x1f\n\x1bPERPETUAL_MARKET_TYPE_CROSS\x10\x01\x12\"\n\x1ePERPETUAL_MARKET_TYPE_ISOLATED\x10\x02\x42>Z<github.com/dydxprotocol/v4-chain/protocol/x/perpetuals/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.perpetuals.perpetual_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z<github.com/dydxprotocol/v4-chain/protocol/x/perpetuals/types'
  _globals['_PERPETUAL'].fields_by_name['params']._loaded_options = None
  _globals['_PERPETUAL'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_PERPETUAL'].fields_by_name['funding_index']._loaded_options = None
  _globals['_PERPETUAL'].fields_by_name['funding_index']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_PERPETUAL'].fields_by_name['open_interest']._loaded_options = None
  _globals['_PERPETUAL'].fields_by_name['open_interest']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_PREMIUMSTORE'].fields_by_name['all_market_premiums']._loaded_options = None
  _globals['_PREMIUMSTORE'].fields_by_name['all_market_premiums']._serialized_options = b'\310\336\037\000'
  _globals['_LIQUIDITYTIER'].fields_by_name['base_position_notional']._loaded_options = None
  _globals['_LIQUIDITYTIER'].fields_by_name['base_position_notional']._serialized_options = b'\030\001'
  _globals['_PERPETUALMARKETTYPE']._serialized_start=982
  _globals['_PERPETUALMARKETTYPE']._serialized_end=1111
  _globals['_PERPETUAL']._serialized_start=91
  _globals['_PERPETUAL']._serialized_end=360
  _globals['_PERPETUALPARAMS']._serialized_start=363
  _globals['_PERPETUALPARAMS']._serialized_end=574
  _globals['_MARKETPREMIUMS']._serialized_start=576
  _globals['_MARKETPREMIUMS']._serialized_end=632
  _globals['_PREMIUMSTORE']._serialized_start=634
  _globals['_PREMIUMSTORE']._serialized_end=746
  _globals['_LIQUIDITYTIER']._serialized_start=749
  _globals['_LIQUIDITYTIER']._serialized_end=979
# @@protoc_insertion_point(module_scope)



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.dydxprotocol.assets import asset_pb2 as _asset_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ("assets",)
    ASSETS_FIELD_NUMBER: _ClassVar[int]
    assets: _containers.RepeatedCompositeFieldContainer[_asset_pb2.Asset]
    def __init__(self, assets: _Optional[_Iterable[_Union[_asset_pb2.Asset, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/bridge/tx.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/bridge/tx.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from v4_proto.dydxprotocol.bridge import bridge_event_pb2 as dydxprotocol_dot_bridge_dot_bridge__event__pb2
from v4_proto.dydxprotocol.bridge import params_pb2 as dydxprotocol_dot_bridge_dot_params__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x64ydxprotocol/bridge/tx.proto\x12\x13\x64ydxprotocol.bridge\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a&dydxprotocol/bridge/bridge_event.proto\x1a dydxprotocol/bridge/params.proto\x1a\x14gogoproto/gogo.proto\"O\n\x15MsgAcknowledgeBridges\x12\x36\n\x06\x65vents\x18\x01 \x03(\x0b\x32 .dydxprotocol.bridge.BridgeEventB\x04\xc8\xde\x1f\x00\"\x1f\n\x1dMsgAcknowledgeBridgesResponse\"\x87\x01\n\x11MsgCompleteBridge\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x35\n\x05\x65vent\x18\x02 \x01(\x0b\x32 .dydxprotocol.bridge.BridgeEventB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\x1b\n\x19MsgCompleteBridgeResponse\"\x8b\x01\n\x14MsgUpdateEventParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x36\n\x06params\x18\x02 \x01(\x0b\x32 .dydxprotocol.bridge.EventParamsB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\x1e\n\x1cMsgUpdateEventParamsResponse\"\x8f\x01\n\x16MsgUpdateProposeParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x38\n\x06params\x18\x02 \x01(\x0b\x32\".dydxprotocol.bridge.ProposeParamsB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\" \n\x1eMsgUpdateProposeParamsResponse\"\x8d\x01\n\x15MsgUpdateSafetyParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x37\n\x06params\x18\x02 \x01(\x0b\x32!.dydxprotocol.bridge.SafetyParamsB\x04\xc8\xde\x1f\x00:\x0e\x82\xe7\xb0*\tauthority\"\x1f\n\x1dMsgUpdateSafetyParamsResponse2\xc7\x04\n\x03Msg\x12t\n\x12\x41\x63knowledgeBridges\x12*.dydxprotocol.bridge.MsgAcknowledgeBridges\x1a\x32.dydxprotocol.bridge.MsgAcknowledgeBridgesResponse\x12h\n\x0e\x43ompleteBridge\x12&.dydxprotocol.bridge.MsgCompleteBridge\x1a..dydxprotocol.bridge.MsgCompleteBridgeResponse\x12q\n\x11UpdateEventParams\x12).dydxprotocol.bridge.MsgUpdateEventParams\x1a\x31.dydxprotocol.bridge.MsgUpdateEventParamsResponse\x12w\n\x13UpdateProposeParams\x12+.dydxprotocol.bridge.MsgUpdateProposeParams\x1a\x33.dydxprotocol.bridge.MsgUpdateProposeParamsResponse\x12t\n\x12UpdateSafetyParams\x12*.dydxprotocol.bridge.MsgUpdateSafetyParams\x1a\x32.dydxprotocol.bridge.MsgUpdateSafetyParamsResponseB:Z8github.com/dydxprotocol/v4-chain/protocol/x/bridge/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.bridge.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z8github.com/dydxprotocol/v4-chain/protocol/x/bridge/types'
  _globals['_MSGACKNOWLEDGEBRIDGES'].fields_by_name['events']._loaded_options = None
  _globals['_MSGACKNOWLEDGEBRIDGES'].fields_by_name['events']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCOMPLETEBRIDGE'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGCOMPLETEBRIDGE'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGCOMPLETEBRIDGE'].fields_by_name['event']._loaded_options = None
  _globals['_MSGCOMPLETEBRIDGE'].fields_by_name['event']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCOMPLETEBRIDGE']._loaded_options = None
  _globals['_MSGCOMPLETEBRIDGE']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGUPDATEEVENTPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEEVENTPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEEVENTPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEEVENTPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEEVENTPARAMS']._loaded_options = None
  _globals['_MSGUPDATEEVENTPARAMS']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGUPDATEPROPOSEPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEPROPOSEPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEPROPOSEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEPROPOSEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEPROPOSEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPROPOSEPARAMS']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGUPDATESAFETYPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATESAFETYPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATESAFETYPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATESAFETYPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATESAFETYPARAMS']._loaded_options = None
  _globals['_MSGUPDATESAFETYPARAMS']._serialized_options = b'\202\347\260*\tauthority'
  _globals['_MSGACKNOWLEDGEBRIDGES']._serialized_start=201
  _globals['_MSGACKNOWLEDGEBRIDGES']._serialized_end=280
  _globals['_MSGACKNOWLEDGEBRIDGESRESPONSE']._serialized_start=282
  _globals['_MSGACKNOWLEDGEBRIDGESRESPONSE']._serialized_end=313
  _globals['_MSGCOMPLETEBRIDGE']._serialized_start=316
  _globals['_MSGCOMPLETEBRIDGE']._serialized_end=451
  _globals['_MSGCOMPLETEBRIDGERESPONSE']._serialized_start=453
  _globals['_MSGCOMPLETEBRIDGERESPONSE']._serialized_end=480
  _globals['_MSGUPDATEEVENTPARAMS']._serialized_start=483
  _globals['_MSGUPDATEEVENTPARAMS']._serialized_end=622
  _globals['_MSGUPDATEEVENTPARAMSRESPONSE']._serialized_start=624
  _globals['_MSGUPDATEEVENTPARAMSRESPONSE']._serialized_end=654
  _globals['_MSGUPDATEPROPOSEPARAMS']._serialized_start=657
  _globals['_MSGUPDATEPROPOSEPARAMS']._serialized_end=800
  _globals['_MSGUPDATEPROPOSEPARAMSRESPONSE']._serialized_start=802
  _globals['_MSGUPDATEPROPOSEPARAMSRESPONSE']._serialized_end=834
  _globals['_MSGUPDATESAFETYPARAMS']._serialized_start=837
  _globals['_MSGUPDATESAFETYPARAMS']._serialized_end=978
  _globals['_MSGUPDATESAFETYPARAMSRESPONSE']._serialized_start=980
  _globals['_MSGUPDATESAFETYPARAMSRESPONSE']._serialized_end=1011
  _globals['_MSG']._serialized_start=1014
  _globals['_MSG']._serialized_end=1597
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/vest/vest_entry.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'dydxprotocol/vest/vest_entry.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"dydxprotocol/vest/vest_entry.proto\x12\x11\x64ydxprotocol.vest\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x14gogoproto/gogo.proto\"\xbe\x01\n\tVestEntry\x12\x16\n\x0evester_account\x18\x01 \x01(\t\x12\x18\n\x10treasury_account\x18\x02 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x03 \x01(\t\x12\x38\n\nstart_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x36\n\x08\x65nd_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x42\x38Z6github.com/dydxprotocol/v4-chain/protocol/x/vest/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.vest.vest_entry_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z6github.com/dydxprotocol/v4-chain/protocol/x/vest/types'
  _globals['_VESTENTRY'].fields_by_name['start_time']._loaded_options = None
  _globals['_VESTENTRY'].fields_by_name['start_time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_VESTENTRY'].fields_by_name['end_time']._loaded_options = None
  _globals['_VESTENTRY'].fields_by_name['end_time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_VESTENTRY']._serialized_start=113
  _globals['_VESTENTRY']._serialized_end=303
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/nft/v1beta1/query.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cosmos/nft/v1beta1/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.cosmos.nft.v1beta1 import nft_pb2 as cosmos_dot_nft_dot_v1beta1_dot_nft__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x63osmos/nft/v1beta1/query.proto\x12\x12\x63osmos.nft.v1beta1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1c\x63osmos/nft/v1beta1/nft.proto\"6\n\x13QueryBalanceRequest\x12\x10\n\x08\x63lass_id\x18\x01 \x01(\t\x12\r\n\x05owner\x18\x02 \x01(\t\"&\n\x14QueryBalanceResponse\x12\x0e\n\x06\x61mount\x18\x01 \x01(\x04\"1\n\x11QueryOwnerRequest\x12\x10\n\x08\x63lass_id\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\"#\n\x12QueryOwnerResponse\x12\r\n\x05owner\x18\x01 \x01(\t\"&\n\x12QuerySupplyRequest\x12\x10\n\x08\x63lass_id\x18\x01 \x01(\t\"%\n\x13QuerySupplyResponse\x12\x0e\n\x06\x61mount\x18\x01 \x01(\x04\"o\n\x10QueryNFTsRequest\x12\x10\n\x08\x63lass_id\x18\x01 \x01(\t\x12\r\n\x05owner\x18\x02 \x01(\t\x12:\n\npagination\x18\x03 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"w\n\x11QueryNFTsResponse\x12%\n\x04nfts\x18\x01 \x03(\x0b\x32\x17.cosmos.nft.v1beta1.NFT\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"/\n\x0fQueryNFTRequest\x12\x10\n\x08\x63lass_id\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\"8\n\x10QueryNFTResponse\x12$\n\x03nft\x18\x01 \x01(\x0b\x32\x17.cosmos.nft.v1beta1.NFT\"%\n\x11QueryClassRequest\x12\x10\n\x08\x63lass_id\x18\x01 \x01(\t\">\n\x12QueryClassResponse\x12(\n\x05\x63lass\x18\x01 \x01(\x0b\x32\x19.cosmos.nft.v1beta1.Class\"Q\n\x13QueryClassesRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x7f\n\x14QueryClassesResponse\x12*\n\x07\x63lasses\x18\x01 \x03(\x0b\x32\x19.cosmos.nft.v1beta1.Class\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse2\xbe\x07\n\x05Query\x12\x94\x01\n\x07\x42\x61lance\x12\'.cosmos.nft.v1beta1.QueryBalanceRequest\x1a(.cosmos.nft.v1beta1.QueryBalanceResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./cosmos/nft/v1beta1/balance/{owner}/{class_id}\x12\x89\x01\n\x05Owner\x12%.cosmos.nft.v1beta1.QueryOwnerRequest\x1a&.cosmos.nft.v1beta1.QueryOwnerResponse\"1\x82\xd3\xe4\x93\x02+\x12)/cosmos/nft/v1beta1/owner/{class_id}/{id}\x12\x88\x01\n\x06Supply\x12&.cosmos.nft.v1beta1.QuerySupplyRequest\x1a\'.cosmos.nft.v1beta1.QuerySupplyResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/cosmos/nft/v1beta1/supply/{class_id}\x12u\n\x04NFTs\x12$.cosmos.nft.v1beta1.QueryNFTsRequest\x1a%.cosmos.nft.v1beta1.QueryNFTsResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/cosmos/nft/v1beta1/nfts\x12\x82\x01\n\x03NFT\x12#.cosmos.nft.v1beta1.QueryNFTRequest\x1a$.cosmos.nft.v1beta1.QueryNFTResponse\"0\x82\xd3\xe4\x93\x02*\x12(/cosmos/nft/v1beta1/nfts/{class_id}/{id}\x12\x86\x01\n\x05\x43lass\x12%.cosmos.nft.v1beta1.QueryClassRequest\x1a&.cosmos.nft.v1beta1.QueryClassResponse\".\x82\xd3\xe4\x93\x02(\x12&/cosmos/nft/v1beta1/classes/{class_id}\x12\x81\x01\n\x07\x43lasses\x12\'.cosmos.nft.v1beta1.QueryClassesRequest\x1a(.cosmos.nft.v1beta1.QueryClassesResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/cosmos/nft/v1beta1/classesB\x14Z\x12\x63osmossdk.io/x/nftb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.nft.v1beta1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\022cosmossdk.io/x/nft'
  _globals['_QUERY'].methods_by_name['Balance']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Balance']._serialized_options = b'\202\323\344\223\0020\022./cosmos/nft/v1beta1/balance/{owner}/{class_id}'
  _globals['_QUERY'].methods_by_name['Owner']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Owner']._serialized_options = b'\202\323\344\223\002+\022)/cosmos/nft/v1beta1/owner/{class_id}/{id}'
  _globals['_QUERY'].methods_by_name['Supply']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Supply']._serialized_options = b'\202\323\344\223\002\'\022%/cosmos/nft/v1beta1/supply/{class_id}'
  _globals['_QUERY'].methods_by_name['NFTs']._loaded_options = None
  _globals['_QUERY'].methods_by_name['NFTs']._serialized_options = b'\202\323\344\223\002\032\022\030/cosmos/nft/v1beta1/nfts'
  _globals['_QUERY'].methods_by_name['NFT']._loaded_options = None
  _globals['_QUERY'].methods_by_name['NFT']._serialized_options = b'\202\323\344\223\002*\022(/cosmos/nft/v1beta1/nfts/{class_id}/{id}'
  _globals['_QUERY'].methods_by_name['Class']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Class']._serialized_options = b'\202\323\344\223\002(\022&/cosmos/nft/v1beta1/classes/{class_id}'
  _globals['_QUERY'].methods_by_name['Classes']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Classes']._serialized_options = b'\202\323\344\223\002\035\022\033/cosmos/nft/v1beta1/classes'
  _globals['_QUERYBALANCEREQUEST']._serialized_start=158
  _globals['_QUERYBALANCEREQUEST']._serialized_end=212
  _globals['_QUERYBALANCERESPONSE']._serialized_start=214
  _globals['_QUERYBALANCERESPONSE']._serialized_end=252
  _globals['_QUERYOWNERREQUEST']._serialized_start=254
  _globals['_QUERYOWNERREQUEST']._serialized_end=303
  _globals['_QUERYOWNERRESPONSE']._serialized_start=305
  _globals['_QUERYOWNERRESPONSE']._serialized_end=340
  _globals['_QUERYSUPPLYREQUEST']._serialized_start=342
  _globals['_QUERYSUPPLYREQUEST']._serialized_end=380
  _globals['_QUERYSUPPLYRESPONSE']._serialized_start=382
  _globals['_QUERYSUPPLYRESPONSE']._serialized_end=419
  _globals['_QUERYNFTSREQUEST']._serialized_start=421
  _globals['_QUERYNFTSREQUEST']._serialized_end=532
  _globals['_QUERYNFTSRESPONSE']._serialized_start=534
  _globals['_QUERYNFTSRESPONSE']._serialized_end=653
  _globals['_QUERYNFTREQUEST']._serialized_start=655
  _globals['_QUERYNFTREQUEST']._serialized_end=702
  _globals['_QUERYNFTRESPONSE']._serialized_start=704
  _globals['_QUERYNFTRESPONSE']._serialized_end=760
  _globals['_QUERYCLASSREQUEST']._serialized_start=762
  _globals['_QUERYCLASSREQUEST']._serialized_end=799
  _globals['_QUERYCLASSRESPONSE']._serialized_start=801
  _globals['_QUERYCLASSRESPONSE']._serialized_end=863
  _globals['_QUERYCLASSESREQUEST']._serialized_start=865
  _globals['_QUERYCLASSESREQUEST']._serialized_end=946
  _globals['_QUERYCLASSESRESPONSE']._serialized_start=948
  _globals['_QUERYCLASSESRESPONSE']._serialized_end=1075
  _globals['_QUERY']._serialized_start=1078
  _globals['_QUERY']._serialized_end=2036
# @@protoc_insertion_point(module_scope)



from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MarketMapperRevShareDetails(_message.Message):
    __slots__ = ("expiration_ts",)
    EXPIRATION_TS_FIELD_NUMBER: _ClassVar[int]
    expiration_ts: int
    def __init__(self, expiration_ts: _Optional[int] = ...) -> None: ...

class UnconditionalRevShareConfig(_message.Message):
    __slots__ = ("configs",)
    class RecipientConfig(_message.Message):
        __slots__ = ("address", "share_ppm")
        ADDRESS_FIELD_NUMBER: _ClassVar[int]
        SHARE_PPM_FIELD_NUMBER: _ClassVar[int]
        address: str
        share_ppm: int
        def __init__(self, address: _Optional[str] = ..., share_ppm: _Optional[int] = ...) -> None: ...
    CONFIGS_FIELD_NUMBER: _ClassVar[int]
    configs: _containers.RepeatedCompositeFieldContainer[UnconditionalRevShareConfig.RecipientConfig]
    def __init__(self, configs: _Optional[_Iterable[_Union[UnconditionalRevShareConfig.RecipientConfig, _Mapping]]] = ...) -> None: ...

class OrderRouterRevShare(_message.Message):
    __slots__ = ("address", "share_ppm")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    SHARE_PPM_FIELD_NUMBER: _ClassVar[int]
    address: str
    share_ppm: int
    def __init__(self, address: _Optional[str] = ..., share_ppm: _Optional[int] = ...) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.dydxprotocol.affiliates import affiliates_pb2 as _affiliates_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenesisState(_message.Message):
    __slots__ = ("affiliate_tiers",)
    AFFILIATE_TIERS_FIELD_NUMBER: _ClassVar[int]
    affiliate_tiers: _affiliates_pb2.AffiliateTiers
    def __init__(self, affiliate_tiers: _Optional[_Union[_affiliates_pb2.AffiliateTiers, _Mapping]] = ...) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.google.api import annotations_pb2 as _annotations_pb2
from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from v4_proto.dydxprotocol.assets import asset_pb2 as _asset_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryAssetRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: int
    def __init__(self, id: _Optional[int] = ...) -> None: ...

class QueryAssetResponse(_message.Message):
    __slots__ = ("asset",)
    ASSET_FIELD_NUMBER: _ClassVar[int]
    asset: _asset_pb2.Asset
    def __init__(self, asset: _Optional[_Union[_asset_pb2.Asset, _Mapping]] = ...) -> None: ...

class QueryAllAssetsRequest(_message.Message):
    __slots__ = ("pagination",)
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    def __init__(self, pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryAllAssetsResponse(_message.Message):
    __slots__ = ("asset", "pagination")
    ASSET_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    asset: _containers.RepeatedCompositeFieldContainer[_asset_pb2.Asset]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, asset: _Optional[_Iterable[_Union[_asset_pb2.Asset, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.dydxprotocol.subaccounts import subaccount_pb2 as _subaccount_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PerpetualLiquidationInfo(_message.Message):
    __slots__ = ("subaccount_id", "perpetual_id")
    SUBACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    PERPETUAL_ID_FIELD_NUMBER: _ClassVar[int]
    subaccount_id: _subaccount_pb2.SubaccountId
    perpetual_id: int
    def __init__(self, subaccount_id: _Optional[_Union[_subaccount_pb2.SubaccountId, _Mapping]] = ..., perpetual_id: _Optional[int] = ...) -> None: ...

class SubaccountLiquidationInfo(_message.Message):
    __slots__ = ("perpetuals_liquidated", "notional_liquidated", "quantums_insurance_lost")
    PERPETUALS_LIQUIDATED_FIELD_NUMBER: _ClassVar[int]
    NOTIONAL_LIQUIDATED_FIELD_NUMBER: _ClassVar[int]
    QUANTUMS_INSURANCE_LOST_FIELD_NUMBER: _ClassVar[int]
    perpetuals_liquidated: _containers.RepeatedScalarFieldContainer[int]
    notional_liquidated: int
    quantums_insurance_lost: int
    def __init__(self, perpetuals_liquidated: _Optional[_Iterable[int]] = ..., notional_liquidated: _Optional[int] = ..., quantums_insurance_lost: _Optional[int] = ...) -> None: ...

class SubaccountOpenPositionInfo(_message.Message):
    __slots__ = ("perpetual_id", "subaccounts_with_long_position", "subaccounts_with_short_position")
    PERPETUAL_ID_FIELD_NUMBER: _ClassVar[int]
    SUBACCOUNTS_WITH_LONG_POSITION_FIELD_NUMBER: _ClassVar[int]
    SUBACCOUNTS_WITH_SHORT_POSITION_FIELD_NUMBER: _ClassVar[int]
    perpetual_id: int
    subaccounts_with_long_position: _containers.RepeatedCompositeFieldContainer[_subaccount_pb2.SubaccountId]
    subaccounts_with_short_position: _containers.RepeatedCompositeFieldContainer[_subaccount_pb2.SubaccountId]
    def __init__(self, perpetual_id: _Optional[int] = ..., subaccounts_with_long_position: _Optional[_Iterable[_Union[_subaccount_pb2.SubaccountId, _Mapping]]] = ..., subaccounts_with_short_position: _Optional[_Iterable[_Union[_subaccount_pb2.SubaccountId, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/vesting/v1beta1/tx.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cosmos/vesting/v1beta1/tx.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.cosmos.vesting.v1beta1 import vesting_pb2 as cosmos_dot_vesting_dot_v1beta1_dot_vesting__pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from v4_proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x63osmos/vesting/v1beta1/tx.proto\x12\x16\x63osmos.vesting.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a$cosmos/vesting/v1beta1/vesting.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x11\x61mino/amino.proto\"\xcb\x02\n\x17MsgCreateVestingAccount\x12.\n\x0c\x66rom_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12,\n\nto_address\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12q\n\x06\x61mount\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBF\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x9a\xe7\xb0*\x0clegacy_coins\xa8\xe7\xb0*\x01\x12\x10\n\x08\x65nd_time\x18\x04 \x01(\x03\x12\x0f\n\x07\x64\x65layed\x18\x05 \x01(\x08:<\xe8\xa0\x1f\x01\x82\xe7\xb0*\x0c\x66rom_address\x8a\xe7\xb0*\"cosmos-sdk/MsgCreateVestingAccount\"!\n\x1fMsgCreateVestingAccountResponse\"\xaf\x02\n\x1fMsgCreatePermanentLockedAccount\x12-\n\x0c\x66rom_address\x18\x01 \x01(\tB\x17\xf2\xde\x1f\x13yaml:\"from_address\"\x12)\n\nto_address\x18\x02 \x01(\tB\x15\xf2\xde\x1f\x11yaml:\"to_address\"\x12q\n\x06\x61mount\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBF\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x9a\xe7\xb0*\x0clegacy_coins\xa8\xe7\xb0*\x01:?\xe8\xa0\x1f\x01\x82\xe7\xb0*\x0c\x66rom_address\x8a\xe7\xb0*%cosmos-sdk/MsgCreatePermLockedAccount\")\n\'MsgCreatePermanentLockedAccountResponse\"\xe4\x01\n\x1fMsgCreatePeriodicVestingAccount\x12\x14\n\x0c\x66rom_address\x18\x01 \x01(\t\x12\x12\n\nto_address\x18\x02 \x01(\t\x12\x12\n\nstart_time\x18\x03 \x01(\x03\x12\x42\n\x0fvesting_periods\x18\x04 \x03(\x0b\x32\x1e.cosmos.vesting.v1beta1.PeriodB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:?\xe8\xa0\x1f\x00\x82\xe7\xb0*\x0c\x66rom_address\x8a\xe7\xb0*%cosmos-sdk/MsgCreatePeriodVestAccount\")\n\'MsgCreatePeriodicVestingAccountResponse2\xc5\x03\n\x03Msg\x12\x80\x01\n\x14\x43reateVestingAccount\x12/.cosmos.vesting.v1beta1.MsgCreateVestingAccount\x1a\x37.cosmos.vesting.v1beta1.MsgCreateVestingAccountResponse\x12\x98\x01\n\x1c\x43reatePermanentLockedAccount\x12\x37.cosmos.vesting.v1beta1.MsgCreatePermanentLockedAccount\x1a?.cosmos.vesting.v1beta1.MsgCreatePermanentLockedAccountResponse\x12\x98\x01\n\x1c\x43reatePeriodicVestingAccount\x12\x37.cosmos.vesting.v1beta1.MsgCreatePeriodicVestingAccount\x1a?.cosmos.vesting.v1beta1.MsgCreatePeriodicVestingAccountResponse\x1a\x05\x80\xe7\xb0*\x01\x42\x33Z1github.com/cosmos/cosmos-sdk/x/auth/vesting/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.vesting.v1beta1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/cosmos/cosmos-sdk/x/auth/vesting/types'
  _globals['_MSGCREATEVESTINGACCOUNT'].fields_by_name['from_address']._loaded_options = None
  _globals['_MSGCREATEVESTINGACCOUNT'].fields_by_name['from_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGCREATEVESTINGACCOUNT'].fields_by_name['to_address']._loaded_options = None
  _globals['_MSGCREATEVESTINGACCOUNT'].fields_by_name['to_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGCREATEVESTINGACCOUNT'].fields_by_name['amount']._loaded_options = None
  _globals['_MSGCREATEVESTINGACCOUNT'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\232\347\260*\014legacy_coins\250\347\260*\001'
  _globals['_MSGCREATEVESTINGACCOUNT']._loaded_options = None
  _globals['_MSGCREATEVESTINGACCOUNT']._serialized_options = b'\350\240\037\001\202\347\260*\014from_address\212\347\260*\"cosmos-sdk/MsgCreateVestingAccount'
  _globals['_MSGCREATEPERMANENTLOCKEDACCOUNT'].fields_by_name['from_address']._loaded_options = None
  _globals['_MSGCREATEPERMANENTLOCKEDACCOUNT'].fields_by_name['from_address']._serialized_options = b'\362\336\037\023yaml:\"from_address\"'
  _globals['_MSGCREATEPERMANENTLOCKEDACCOUNT'].fields_by_name['to_address']._loaded_options = None
  _globals['_MSGCREATEPERMANENTLOCKEDACCOUNT'].fields_by_name['to_address']._serialized_options = b'\362\336\037\021yaml:\"to_address\"'
  _globals['_MSGCREATEPERMANENTLOCKEDACCOUNT'].fields_by_name['amount']._loaded_options = None
  _globals['_MSGCREATEPERMANENTLOCKEDACCOUNT'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\232\347\260*\014legacy_coins\250\347\260*\001'
  _globals['_MSGCREATEPERMANENTLOCKEDACCOUNT']._loaded_options = None
  _globals['_MSGCREATEPERMANENTLOCKEDACCOUNT']._serialized_options = b'\350\240\037\001\202\347\260*\014from_address\212\347\260*%cosmos-sdk/MsgCreatePermLockedAccount'
  _globals['_MSGCREATEPERIODICVESTINGACCOUNT'].fields_by_name['vesting_periods']._loaded_options = None
  _globals['_MSGCREATEPERIODICVESTINGACCOUNT'].fields_by_name['vesting_periods']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGCREATEPERIODICVESTINGACCOUNT']._loaded_options = None
  _globals['_MSGCREATEPERIODICVESTINGACCOUNT']._serialized_options = b'\350\240\037\000\202\347\260*\014from_address\212\347\260*%cosmos-sdk/MsgCreatePeriodVestAccount'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGCREATEVESTINGACCOUNT']._serialized_start=223
  _globals['_MSGCREATEVESTINGACCOUNT']._serialized_end=554
  _globals['_MSGCREATEVESTINGACCOUNTRESPONSE']._serialized_start=556
  _globals['_MSGCREATEVESTINGACCOUNTRESPONSE']._serialized_end=589
  _globals['_MSGCREATEPERMANENTLOCKEDACCOUNT']._serialized_start=592
  _globals['_MSGCREATEPERMANENTLOCKEDACCOUNT']._serialized_end=895
  _globals['_MSGCREATEPERMANENTLOCKEDACCOUNTRESPONSE']._serialized_start=897
  _globals['_MSGCREATEPERMANENTLOCKEDACCOUNTRESPONSE']._serialized_end=938
  _globals['_MSGCREATEPERIODICVESTINGACCOUNT']._serialized_start=941
  _globals['_MSGCREATEPERIODICVESTINGACCOUNT']._serialized_end=1169
  _globals['_MSGCREATEPERIODICVESTINGACCOUNTRESPONSE']._serialized_start=1171
  _globals['_MSGCREATEPERIODICVESTINGACCOUNTRESPONSE']._serialized_end=1212
  _globals['_MSG']._serialized_start=1215
  _globals['_MSG']._serialized_end=1668
# @@protoc_insertion_point(module_scope)



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.amino import amino_pb2 as _amino_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Params(_message.Message):
    __slots__ = ("community_tax", "base_proposer_reward", "bonus_proposer_reward", "withdraw_addr_enabled")
    COMMUNITY_TAX_FIELD_NUMBER: _ClassVar[int]
    BASE_PROPOSER_REWARD_FIELD_NUMBER: _ClassVar[int]
    BONUS_PROPOSER_REWARD_FIELD_NUMBER: _ClassVar[int]
    WITHDRAW_ADDR_ENABLED_FIELD_NUMBER: _ClassVar[int]
    community_tax: str
    base_proposer_reward: str
    bonus_proposer_reward: str
    withdraw_addr_enabled: bool
    def __init__(self, community_tax: _Optional[str] = ..., base_proposer_reward: _Optional[str] = ..., bonus_proposer_reward: _Optional[str] = ..., withdraw_addr_enabled: bool = ...) -> None: ...

class ValidatorHistoricalRewards(_message.Message):
    __slots__ = ("cumulative_reward_ratio", "reference_count")
    CUMULATIVE_REWARD_RATIO_FIELD_NUMBER: _ClassVar[int]
    REFERENCE_COUNT_FIELD_NUMBER: _ClassVar[int]
    cumulative_reward_ratio: _containers.RepeatedCompositeFieldContainer[_coin_pb2.DecCoin]
    reference_count: int
    def __init__(self, cumulative_reward_ratio: _Optional[_Iterable[_Union[_coin_pb2.DecCoin, _Mapping]]] = ..., reference_count: _Optional[int] = ...) -> None: ...

class ValidatorCurrentRewards(_message.Message):
    __slots__ = ("rewards", "period")
    REWARDS_FIELD_NUMBER: _ClassVar[int]
    PERIOD_FIELD_NUMBER: _ClassVar[int]
    rewards: _containers.RepeatedCompositeFieldContainer[_coin_pb2.DecCoin]
    period: int
    def __init__(self, rewards: _Optional[_Iterable[_Union[_coin_pb2.DecCoin, _Mapping]]] = ..., period: _Optional[int] = ...) -> None: ...

class ValidatorAccumulatedCommission(_message.Message):
    __slots__ = ("commission",)
    COMMISSION_FIELD_NUMBER: _ClassVar[int]
    commission: _containers.RepeatedCompositeFieldContainer[_coin_pb2.DecCoin]
    def __init__(self, commission: _Optional[_Iterable[_Union[_coin_pb2.DecCoin, _Mapping]]] = ...) -> None: ...

class ValidatorOutstandingRewards(_message.Message):
    __slots__ = ("rewards",)
    REWARDS_FIELD_NUMBER: _ClassVar[int]
    rewards: _containers.RepeatedCompositeFieldContainer[_coin_pb2.DecCoin]
    def __init__(self, rewards: _Optional[_Iterable[_Union[_coin_pb2.DecCoin, _Mapping]]] = ...) -> None: ...

class ValidatorSlashEvent(_message.Message):
    __slots__ = ("validator_period", "fraction")
    VALIDATOR_PERIOD_FIELD_NUMBER: _ClassVar[int]
    FRACTION_FIELD_NUMBER: _ClassVar[int]
    validator_period: int
    fraction: str
    def __init__(self, validator_period: _Optional[int] = ..., fraction: _Optional[str] = ...) -> None: ...

class ValidatorSlashEvents(_message.Message):
    __slots__ = ("validator_slash_events",)
    VALIDATOR_SLASH_EVENTS_FIELD_NUMBER: _ClassVar[int]
    validator_slash_events: _containers.RepeatedCompositeFieldContainer[ValidatorSlashEvent]
    def __init__(self, validator_slash_events: _Optional[_Iterable[_Union[ValidatorSlashEvent, _Mapping]]] = ...) -> None: ...

class FeePool(_message.Message):
    __slots__ = ("community_pool",)
    COMMUNITY_POOL_FIELD_NUMBER: _ClassVar[int]
    community_pool: _containers.RepeatedCompositeFieldContainer[_coin_pb2.DecCoin]
    def __init__(self, community_pool: _Optional[_Iterable[_Union[_coin_pb2.DecCoin, _Mapping]]] = ...) -> None: ...

class CommunityPoolSpendProposal(_message.Message):
    __slots__ = ("title", "description", "recipient", "amount")
    TITLE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    RECIPIENT_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    title: str
    description: str
    recipient: str
    amount: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    def __init__(self, title: _Optional[str] = ..., description: _Optional[str] = ..., recipient: _Optional[str] = ..., amount: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ...) -> None: ...

class DelegatorStartingInfo(_message.Message):
    __slots__ = ("previous_period", "stake", "height")
    PREVIOUS_PERIOD_FIELD_NUMBER: _ClassVar[int]
    STAKE_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    previous_period: int
    stake: str
    height: int
    def __init__(self, previous_period: _Optional[int] = ..., stake: _Optional[str] = ..., height: _Optional[int] = ...) -> None: ...

class DelegationDelegatorReward(_message.Message):
    __slots__ = ("validator_address", "reward")
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    REWARD_FIELD_NUMBER: _ClassVar[int]
    validator_address: str
    reward: _containers.RepeatedCompositeFieldContainer[_coin_pb2.DecCoin]
    def __init__(self, validator_address: _Optional[str] = ..., reward: _Optional[_Iterable[_Union[_coin_pb2.DecCoin, _Mapping]]] = ...) -> None: ...

class CommunityPoolSpendProposalWithDeposit(_message.Message):
    __slots__ = ("title", "description", "recipient", "amount", "deposit")
    TITLE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    RECIPIENT_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    DEPOSIT_FIELD_NUMBER: _ClassVar[int]
    title: str
    description: str
    recipient: str
    amount: str
    deposit: str
    def __init__(self, title: _Optional[str] = ..., description: _Optional[str] = ..., recipient: _Optional[str] = ..., amount: _Optional[str] = ..., deposit: _Optional[str] = ...) -> None: ...
